## Release history

### 0.2.0 - alpha (2021-08-01)

* Added new operations and plugins.
* Improved existing operations and plugins.
* Implemented sessions, allowing users to save and load authentication data.
* Implemented basic fuzzing.
* Multiple bug fixes.
* Project directory changed from ``~/.config/raider/apps`` to
  ``~/.config/raider/projects``.
* Updated documentation.


### 0.1.3 - prototype (2021-07-20)

* Raider became open source.
* Package published on PyPi.
* Documentation published on readthedocs.
